@@ -414,7 +414,7 @@ public class TextAreaPainter extends JComponent implements TabExpander {
 			}
 		} catch (Exception e) {
 			System.err.println("Error repainting line" + " range {" + firstInvalid + "," + lastInvalid + "}:");
-			e.printStackTrace();
+//			e.printStackTrace();
 		}
 	}
 
